<!DOCTYPE html>
<html>
  <head>
    <meta charset="UTF-8">
    <title>Log In | AnyoneAI</title>
    <style>
    .content {
     
      padding-top: 24px;
      position: absolute;
      top: 50%;
      left: 50%;
      -ms-transform: translate(-50%, -50%);
      transform: translate(-50%, -50%);
      border: 1px solid #dadce0;
      border-radius: 8px;
      font-family: Google Sans, "Poppins", -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Open Sans', 'Helvetica Neue', sans-serif;
      width: 450px;
      margin-top: auto;
      text-align: center;
      display: block;
      margin-right: auto;
      margin-bottom: auto;
      margin-left: auto;
    }

    h1 {
      font-variant: normal;
      font-style: normal;
      font-weight: 100;
    }
    </style>
    <script src="https://www.gstatic.com/firebasejs/5.10.1/firebase.js"></script>
    <script>
    var config = {
      apiKey: "AIzaSyA_D-WdLGouLNJw8GwfXe14upgVHHAELVA",
      authDomain: "anyone-ai.firebaseapp.com",
      databaseURL: "https://anyone-ai.firebaseio.com",
      projectId: "anyone-ai",
      storageBucket: "anyone-ai.appspot.com",
      messagingSenderId: "425044191127",
      appId: "1:425044191127:web:053d78091ed8a8542586d2"
    };
    firebase.initializeApp(config);
    </script>
    <script src="https://cdn.firebase.com/libs/firebaseui/3.6.0/firebaseui.js"></script>
    <link type="text/css" rel="stylesheet" href="https://cdn.firebase.com/libs/firebaseui/3.6.0/firebaseui.css" />
    <script type="text/javascript">
      var uiConfig = {
        signInSuccessUrl: '../',
        signInOptions: [
          firebase.auth.GoogleAuthProvider.PROVIDER_ID,
          firebase.auth.EmailAuthProvider.PROVIDER_ID,
        ],
        tosUrl: '<your-tos-url>',
        privacyPolicyUrl: function() {
          window.location.assign('<your-privacy-policy-url>');
        }
      };

      var ui = new firebaseui.auth.AuthUI(firebase.auth());
      ui.start('#firebaseui-auth-container', uiConfig);
    </script>
  </head>
  <body>
    <div class="content">
      <h1>Log In . AnyoneAI</h1>
      <br>
      <div id="firebaseui-auth-container"></div>

    </div>
  </body>
</html>